@@ -1,5 +1,5 @@
 package Business::AuthorizeNet::CIM;
-$Business::AuthorizeNet::CIM::VERSION = '0.09';
+$Business::AuthorizeNet::CIM::VERSION = '0.10';
 
 # ABSTRACT: Authorize.Net Customer Information Manager (CIM) Web Services API
 
@@ -557,7 +557,7 @@ sub getCustomerShippingAddressRequest {
 }
 
 sub getHostedProfilePageRequest {
-    my ( $self, $customerProfileId ) = @_;
+    my ( $self, $customerProfileId, $args ) = @_;
 
     my $xml;
     my $writer = XML::Writer->new( OUTPUT => \$xml );
@@ -568,6 +568,18 @@ sub getHostedProfilePageRequest {
     $writer->dataElement( 'transactionKey', $self->{transactionKey} );
     $writer->endTag('merchantAuthentication');
     $writer->dataElement( 'customerProfileId', $customerProfileId );
+
+    if ($args) {
+        $writer->startTag('hostedProfileSettings');
+        foreach my $name ( keys %{$args} ) {
+            $writer->startTag('setting');
+            $writer->dataElement( 'settingName',  $name );
+            $writer->dataElement( 'settingValue', $args->{$name} );
+            $writer->endTag('setting');
+        }
+        $writer->endTag('hostedProfileSettings');
+    }
+
     $writer->endTag('getHostedProfilePageRequest');
 
     $xml = '<?xml version="1.0" encoding="utf-8"?>' . "\n" . $xml;
@@ -810,7 +822,7 @@ Business::AuthorizeNet::CIM - Authorize.Net Customer Information Manager (CIM) W
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -1143,7 +1155,21 @@ Retrieve a customer shipping address for an existing customer profile.
 
 Get a token for use in a CIM hosted popup.
 
-    my $result = $cim->getHostedProfilePageRequest($customerProfileId);
+    my $result = $cim->getHostedProfilePageRequest(
+        customerProfileID,
+    {
+        hostedProfileReturnUrl         => 'http://example.com/foo',
+        hostedProfileReturnUrlText     => 'Return home',
+        hostedProfilePageBorderVisible => 'true',
+        hostedProfileHeadingBgColor    => '#000',
+        hostedProfileIFrameCommunicatorUrl =>
+            'https://example.com/communicate',
+        hostedProfileValidationMode         => 'testMode',
+        hostedProfileBillingAddressRequired => 'true',
+        hostedProfileCardCodeRequired       => 'true',
+    }
+
+    );
     print $result->{token} if $result->{messages}->{resultCode} eq 'Ok';
 
 =head3 updateCustomerProfile
@@ -1252,6 +1278,10 @@ Fayland Lam <fayland@gmail.com>
 
 Rhesa Rozendaal
 
+=item *
+
+Olaf Alders
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
